# Registry for Frictionless Energy data (Friendly data)

This is the column schema registry for the Frictionless Energy data
implementation developed by the SENTINEL collaboration.

Documentation can be found in the Friendly data
[documentation](https://sentinel-energy.github.io/friendly_data/registry.html).
